grib2io.tables.originating_centers API documentation

# grib2io.tables.originating_centers

View Source

      1table_originating_centers  = {
      2'1':'Melbourne (WMC)',
      3'2':'Melbourne (WMC)',
      4'3':'Melbourne (WMC)',
      5'4':'Moscow (WMC)',
      6'5':'Moscow (WMC)',
      7'6':'Moscow (WMC)',
      8'7':'US National Weather Service - NCEP (WMC)',
      9'8':'US National Weather Service - NWSTG (WMC)',
     10'9':'US National Weather Service - Other (WMC)',
     11'10':'Cairo (RSMC/RAFC)',
     12'11':'Cairo (RSMC/RAFC)',
     13'12':'Dakar (RSMC/RAFC)',
     14'13':'Dakar (RSMC/RAFC)',
     15'14':'Nairobi (RSMC/RAFC)',
     16'15':'Nairobi (RSMC/RAFC)',
     17'16':'Casablanca (RSMC)',
     18'17':'Tunis (RSMC)',
     19'18':'Tunis-Casablanca (RSMC)',
     20'19':'Tunis-Casablanca (RSMC)',
     21'20':'Las Palmas (RAFC)',
     22'21':'Algiers (RSMC)',
     23'22':'ACMAD',
     24'23':'Mozambique (NMC)',
     25'24':'Pretoria (RSMC)',
     26'25':'La Reunion (RSMC)',
     27'26':'Khabarovsk (RSMC)',
     28'27':'Khabarovsk (RSMC)',
     29'28':'New Delhi (RSMC/RAFC)',
     30'29':'New Delhi (RSMC/RAFC)',
     31'30':'Novosibirsk (RSMC)',
     32'31':'Novosibirsk (RSMC)',
     33'32':'Tashkent (RSMC)',
     34'33':'Jeddah (RSMC)',
     35'34':'Tokyo (RSMC), Japanese Meteorological Agency',
     36'35':'Tokyo (RSMC), Japanese Meteorological Agency',
     37'36':'Bankok',
     38'37':'Ulan Bator',
     39'38':'Beijing (RSMC)',
     40'39':'Beijing (RSMC)',
     41'40':'Seoul',
     42'41':'Buenos Aires (RSMC/RAFC)',
     43'42':'Buenos Aires (RSMC/RAFC)',
     44'43':'Brasilia (RSMC/RAFC)',
     45'44':'Brasilia (RSMC/RAFC)',
     46'45':'Santiago',
     47'46':'Brazilian Space Agency - INPE',
     48'47':'Columbia (NMC)',
     49'48':'Ecuador (NMC)',
     50'49':'Peru (NMC)',
     51'50':'Venezuela (NMC)',
     52'51':'Miami (RSMC/RAFC)',
     53'52':'Miami (RSMC), National Hurricane Center',
     54'53':'Canadian Meteorological Service - Montreal (RSMC)',
     55'54':'Canadian Meteorological Service - Montreal (RSMC)',
     56'55':'San Francisco',
     57'56':'ARINC Center',
     58'57':'US Air Force - Air Force Global Weather Center',
     59'58':'Fleet Numerical Meteorology and Oceanography Center,Monterey,CA,USA',
     60'59':'The NOAA Forecast Systems Lab, Boulder, CO, USA',
     61'60':'National Center for Atmospheric Research (NCAR), Boulder, CO',
     62'61':'Service ARGOS - Landover, MD, USA',
     63'62':'US Naval Oceanographic Office',
     64'63':'International Research Institude for Climate and Society',
     65'64':'Honolulu',
     66'65':'Darwin (RSMC)',
     67'66':'Darwin (RSMC)',
     68'67':'Melbourne (RSMC)',
     69'68':'Reserved',
     70'69':'Wellington (RSMC/RAFC)',
     71'70':'Wellington (RSMC/RAFC)',
     72'71':'Nadi (RSMC)',
     73'72':'Singapore',
     74'73':'Malaysia (NMC)',
     75'74':'U.K. Met Office - Exeter (RSMC)',
     76'75':'U.K. Met Office - Exeter (RSMC)',
     77'76':'Moscow (RSMC/RAFC)',
     78'77':'Reserved',
     79'78':'Offenbach (RSMC)',
     80'79':'Offenbach (RSMC)',
     81'80':'Rome (RSMC)',
     82'81':'Rome (RSMC)',
     83'82':'Norrkoping',
     84'83':'Norrkoping',
     85'84':'French Weather Service - Toulouse',
     86'85':'French Weather Service - Toulouse',
     87'86':'Helsinki',
     88'87':'Belgrade',
     89'88':'Oslo',
     90'89':'Prague',
     91'90':'Episkopi',
     92'91':'Ankara',
     93'92':'Frankfurt/Main (RAFC)',
     94'93':'London (WAFC)',
     95'94':'Copenhagen',
     96'95':'Rota',
     97'96':'Athens',
     98'97':'European Space Agency (ESA)',
     99'98':'European Center for Medium-Range Weather Forecasts (RSMC)',
    100'99':'De Bilt, Netherlands',
    101'100':'Brazzaville',
    102'101':'Abidjan',
    103'102':'Libyan Arab Jamahiriya (NMC)',
    104'103':'Madagascar (NMC)',
    105'104':'Mauritius (NMC)',
    106'105':'Niger (NMC)',
    107'106':'Seychelles (NMC)',
    108'107':'Uganda (NMC)',
    109'108':'United Republic of Tanzania (NMC)',
    110'109':'Zimbabwe (NMC)',
    111'110':'Hong-Kong',
    112'111':'Afghanistan (NMC)',
    113'112':'Bahrain (NMC)',
    114'113':'Bangladesh (NMC)',
    115'114':'Bhutan (NMC)',
    116'115':'Cambodia (NMC)',
    117'116':'Democratic Peoples Republic of Korea (NMC)',
    118'117':'Islamic Republic of Iran (NMC)',
    119'118':'Iraq (NMC)',
    120'119':'Kazakhstan (NMC)',
    121'120':'Kuwait (NMC)',
    122'121':'Kyrgyz Republic (NMC)',
    123'122':'Lao Peoples Democratic Republic (NMC)',
    124'123':'Macao, China',
    125'124':'Maldives (NMC)',
    126'125':'Myanmar (NMC)',
    127'126':'Nepal (NMC)',
    128'127':'Oman (NMC)',
    129'128':'Pakistan (NMC)',
    130'129':'Qatar (NMC)',
    131'130':'Yemen (NMC)',
    132'131':'Sri Lanka (NMC)',
    133'132':'Tajikistan (NMC)',
    134'133':'Turkmenistan (NMC)',
    135'134':'United Arab Emirates (NMC)',
    136'135':'Uzbekistan (NMC)',
    137'136':'Viet Nam (NMC)',
    138'137-139':'Reserved',
    139'140':'Bolivia (NMC)',
    140'141':'Guyana (NMC)',
    141'142':'Paraguay (NMC)',
    142'143':'Suriname (NMC)',
    143'144':'Uruguay (NMC)',
    144'145':'French Guyana',
    145'146':'Brazilian Navy Hydrographic Center',
    146'147':'National Commission on Space Activities - Argentina',
    147'148':'Brazilian Department of Airspace  Control - DECEA',
    148'149':'Reserved',
    149'150':'Antigua and Barbuda (NMC)',
    150'151':'Bahamas (NMC)',
    151'152':'Barbados (NMC)',
    152'153':'Belize (NMC)',
    153'154':'British Caribbean Territories Center',
    154'155':'San Jose',
    155'156':'Cuba (NMC)',
    156'157':'Dominica (NMC)',
    157'158':'Dominican Republic (NMC)',
    158'159':'El Salvador (NMC)',
    159'160':'US NOAA/NESDIS',
    160'161':'US NOAA Office of Oceanic and Atmospheric Research',
    161'162':'Guatemala (NMC)',
    162'163':'Haiti (NMC)',
    163'164':'Honduras (NMC)',
    164'165':'Jamaica (NMC)',
    165'166':'Mexico City',
    166'167':'Netherlands Antilles and Aruba (NMC)',
    167'168':'Nicaragua (NMC)',
    168'169':'Panama (NMC)',
    169'170':'Saint Lucia (NMC)',
    170'171':'Trinidad and Tobago (NMC)',
    171'172':'French Departments in RA IV',
    172'173':'US National Aeronautics and Space Administration (NASA)',
    173'174':'Integrated System Data Management/Marine Environmental Data Service (ISDM/MEDS) - Canada',
    174'175':'Reserved',
    175'176':'US Cooperative Institude for Meteorological Satellite Studies',
    176'177-189':'Reserved',
    177'190':'Cook Islands (NMC)',
    178'191':'French Polynesia (NMC)',
    179'192':'Tonga (NMC)',
    180'193':'Vanuatu (NMC)',
    181'194':'Brunei (NMC)',
    182'195':'Indonesia (NMC)',
    183'196':'Kiribati (NMC)',
    184'197':'Federated States of Micronesia (NMC)',
    185'198':'New Caledonia (NMC)',
    186'199':'Niue',
    187'200':'Papua New Guinea (NMC)',
    188'201':'Philippines (NMC)',
    189'202':'Samoa (NMC)',
    190'203':'Solomon Islands (NMC)',
    191'204':'Narional Institude of Water and Atmospheric Research - New Zealand',
    192'205-209':'Reserved',
    193'210':'Frascati (ESA/ESRIN)',
    194'211':'Lanion',
    195'212':'Lisbon',
    196'213':'Reykjavik',
    197'214':'Madrid',
    198'215':'Zurich',
    199'216':'Service ARGOS - Toulouse',
    200'217':'Bratislava',
    201'218':'Budapest',
    202'219':'Ljubljana',
    203'220':'Warsaw',
    204'221':'Zagreb',
    205'222':'Albania (NMC)',
    206'223':'Armenia (NMC)',
    207'224':'Austria (NMC)',
    208'225':'Azerbaijan (NMC)',
    209'226':'Belarus (NMC)',
    210'227':'Belgium (NMC)',
    211'228':'Bosnia and Herzegovina (NMC)',
    212'229':'Bulgaria (NMC)',
    213'230':'Cyprus (NMC)',
    214'231':'Estonia (NMC)',
    215'232':'Georgia (NMC)',
    216'233':'Dublin',
    217'234':'Israel (NMC)',
    218'235':'Jordan (NMC)',
    219'236':'Latvia (NMC)',
    220'237':'Lebanon (NMC)',
    221'238':'Lithuania (NMC)',
    222'239':'Luxembourg',
    223'240':'Malta (NMC)',
    224'241':'Monaco',
    225'242':'Romania (NMC)',
    226'243':'Syrian Arab Republic (NMC)',
    227'244':'The former Yugoslav Republic of Macedonia (NMC)',
    228'245':'Ukraine (NMC)',
    229'246':'Republic of Moldova (NMC)',
    230'247':'Operational Programme for the Exchange  of Weather RAdar Information (OPERA) - EUMETNET',
    231'248-249':'Reserved',
    232'250':'COnsortium for Small scale MOdelling (COSMO)',
    233'251-253':'Reserved',
    234'254':'EUMETSAT Operations Center',
    235'255':'Missing Value',
    236}
    237
    238table_originating_subcenters  = {
    239'1':'NCEP Re-Analysis Project',
    240'2':'NCEP Ensemble Products',
    241'3':'NCEP Central Operations',
    242'4':'Environmental Modeling Center',
    243'5':'Weather Prediction Center',
    244'6':'Ocean Prediction Center',
    245'7':'Climate Prediction Center',
    246'8':'Aviation Weather Center',
    247'9':'Storm Prediction Center',
    248'10':'National Hurricane Center',
    249'11':'NWS Techniques Development Laboratory',
    250'12':'NESDIS Office of Research and Applications',
    251'13':'Federal Aviation Administration',
    252'14':'NWS Meteorological Development Laboratory',
    253'15':'North American Regional Reanalysis Project',
    254'16':'Space Weather Prediction Center',
    255'17':'ESRL Global Systems Division',
    256}
    257
    258table_generating_process  = {
    259'0-1':'Reserved',
    260'2':'Ultra Violet Index Model',
    261'3':'NCEP/ARL Transport and Dispersion Model',
    262'4':'NCEP/ARL Smoke Model',
    263'5':'Satellite Derived Precipitation and temperatures, from IR (See PDS Octet 41 ... for specific satellite ID)',
    264'6':'NCEP/ARL Dust Model',
    265'7-9':'Reserved',
    266'10':'Global Wind-Wave Forecast Model',
    267'11':'Global Multi-Grid Wave Model (Static Grids)',
    268'12':'Probabilistic Storm Surge (P-Surge)',
    269'13':'Hurricane Multi-Grid Wave Model',
    270'14':'Extra-tropical Storm Surge Atlantic Domain',
    271'15':'Nearshore Wave Prediction System (NWPS)',
    272'16':'Extra-Tropical Storm Surge (ETSS)',
    273'17':'Extra-tropical Storm Surge Pacific Domain',
    274'18':'Probabilistic Extra-Tropical Storm Surge (P-ETSS)',
    275'19':'Reserved',
    276'20':'Extra-tropical Storm Surge Micronesia Domain',
    277'21-24':'Reserved',
    278'25':'Snow Cover Analysis',
    279'26-29':'Reserved',
    280'30':'Forecaster generated field',
    281'31':'Value added post processed field',
    282'32-41':'Reserved',
    283'42':'Global Optimum Interpolation Analysis (GOI) from GFS model',
    284'43':'Global Optimum Interpolation Analysis (GOI) from "Final" run',
    285'44':'Sea Surface Temperature Analysis',
    286'45':'Coastal Ocean Circulation Model',
    287'46':'HYCOM - Global',
    288'47':'HYCOM - North Pacific basin',
    289'48':'HYCOM - North Atlantic basin',
    290'49':'Ozone Analysis from TIROS Observations',
    291'50-51':'Reserved',
    292'52':'Ozone Analysis from Nimbus 7 Observations',
    293'53-63':'Reserved',
    294'64':'Regional Optimum Interpolation Analysis (ROI)',
    295'65-67':'Reserved',
    296'68':'80 wave triangular, 18-layer Spectral model from GFS model',
    297'69':'80 wave triangular, 18 layer Spectral model from "Medium Range Forecast" run',
    298'70':'Quasi-Lagrangian Hurricane Model (QLM)',
    299'71':'Hurricane Weather Research and Forecasting (HWRF)',
    300'72':'Hurricane Non-Hydrostatic Multiscale Model on the B Grid (HNMMB)',
    301'73':'Fog Forecast model - Ocean Prod. Center',
    302'74':'Gulf of Mexico Wind/Wave',
    303'75':'Gulf of Alaska Wind/Wave',
    304'76':'Bias corrected Medium Range Forecast',
    305'77':'126 wave triangular, 28 layer Spectral model from GFS model',
    306'78':'126 wave triangular, 28 layer Spectral model from "Medium Range Forecast" run',
    307'79':'Reserved',
    308'80':'62 wave triangular, 28 layer Spectral model from "Medium Range Forecast" run',
    309'81':'Analysis from GFS (Global Forecast System)',
    310'82':'Analysis from GDAS (Global Data Assimilation System)',
    311'83':'High Resolution Rapid Refresh (HRRR)',
    312'84':'MESO NAM Model (currently 12 km)',
    313'85':'Real Time Ocean Forecast System (RTOFS)',
    314'86':'Early Hurricane Wind Speed Probability Model',
    315'87':'CAC Ensemble Forecasts from Spectral (ENSMB)',
    316'88':'NOAA Wave Watch III (NWW3) Ocean Wave Model',
    317'89':'Non-hydrostatic Meso Model (NMM) (Currently 8 km)',
    318'90':'62 wave triangular, 28 layer spectral model extension of the "Medium Range Forecast" run',
    319'91':'62 wave triangular, 28 layer spectral model extension of the GFS model',
    320'92':'62 wave triangular, 28 layer spectral model run from the "Medium Range Forecast" final analysis',
    321'93':'62 wave triangular, 28 layer spectral model run from the T62 GDAS analysis of the "Medium Range Forecast" run',
    322'94':'T170/L42 Global Spectral Model from MRF run',
    323'95':'T126/L42 Global Spectral Model from MRF run',
    324'96':'Global Forecast System Model  T1534 - Forecast hours 00-384 T574 - Forecast hours 00-192 T190 - Forecast hours 204-384',
    325'97':'Reserved',
    326'98':'Climate Forecast System Model -- Atmospheric model (GFS) coupled to a multi level ocean model . Currently GFS spectral model at T62, 64 levels coupled to 40 level MOM3 ocean model.',
    327'99':'Miscellaneous Test ID',
    328'100':'Miscellaneous Test ID',
    329'101':'Conventional Observation Re-Analysis (CORE)',
    330'102-103':'Reserved',
    331'104':'National Blend GRIB',
    332'105':'Rapid Refresh (RAP)',
    333'106':'Reserved',
    334'107':'Global Ensemble Forecast System (GEFS)',
    335'108':'Localized Aviation MOS Program (LAMP)',
    336'109':'Real Time Mesoscale Analysis (RTMA)',
    337'110':'NAM Model - 15km version',
    338'111':'NAM model, generic resolution (Used in SREF processing)',
    339'112':'WRF-NMM model, generic resolution (Used in various runs) NMM=Nondydrostatic Mesoscale Model (NCEP)',
    340'113':'Products from NCEP SREF processing',
    341'114':'NAEFS Products from joined NCEP, CMC global ensembles',
    342'115':'Downscaled GFS from NAM eXtension',
    343'116':'WRF-EM model, generic resolution (Used in various runs) EM - Eulerian Mass-core (NCAR - aka Advanced Research WRF)',
    344'117':'NEMS GFS Aerosol Component',
    345'118':'UnRestricted Mesoscale Analysis (URMA)',
    346'119':'WAM (Whole Atmosphere Model)',
    347'120':'Ice Concentration Analysis',
    348'121':'Western North Atlantic Regional Wave Model',
    349'122':'Alaska Waters Regional Wave Model',
    350'123':'North Atlantic Hurricane Wave Model',
    351'124':'Eastern North Pacific Regional Wave Model',
    352'125':'North Pacific Hurricane Wave Model',
    353'126':'Sea Ice Forecast Model',
    354'127':'Lake Ice Forecast Model',
    355'128':'Global Ocean Forecast Model',
    356'129':'Global Ocean Data Analysis System (GODAS)',
    357'130':'Merge of fields from the RUC, NAM, and Spectral Model',
    358'131':'Great Lakes Wave Model',
    359'132':'High Resolution Ensemble Forecast (HREF)',
    360'133':'Great Lakes Short Range Wave Model',
    361'134':'Rapid Refresh Forecast System (RRFS)',
    362'135':'Hurricane Analysis and Forecast System (HAFS)',
    363'136-139':'Reserved',
    364'140':'North American Regional Reanalysis (NARR)',
    365'141':'Land Data Assimilation and Forecast System',
    366'142-149':'Reserved',
    367'150':'NWS River Forecast System (NWSRFS)',
    368'151':'NWS Flash Flood Guidance System (NWSFFGS)',
    369'152':'WSR-88D Stage II Precipitation Analysis',
    370'153':'WSR-88D Stage III Precipitation Analysis',
    371'154-179':'Reserved',
    372'180':'Quantitative Precipitation Forecast generated by NCEP',
    373'181':'River Forecast Center Quantitative Precipitation Forecast mosaic generated by NCEP',
    374'182':'River Forecast Center Quantitative Precipitation estimate mosaic generated by NCEP',
    375'183':'NDFD product generated by NCEP/HPC',
    376'184':'Climatological Calibrated Precipitation Analysis (CCPA)',
    377'185-189':'Reserved',
    378'190':'National Convective Weather Diagnostic generated by NCEP/AWC',
    379'191':'Current Icing Potential automated product genterated by NCEP/AWC',
    380'192':'Analysis product from NCEP/AWC',
    381'193':'Forecast product from NCEP/AWC',
    382'194':'Reserved',
    383'195':'Climate Data Assimilation System 2 (CDAS2)',
    384'196':'Climate Data Assimilation System 2 (CDAS2) - used for regeneration runs',
    385'197':'Climate Data Assimilation System (CDAS)',
    386'198':'Climate Data Assimilation System (CDAS) - used for regeneration runs',
    387'199':'Climate Forecast System Reanalysis (CFSR) -- Atmospheric model (GFS) coupled to a multi level ocean, land and seaice model. GFS spectral model at T382, 64 levels coupled to 40 level MOM4 ocean model.',
    388'200':'CPC Manual Forecast Product',
    389'201':'CPC Automated Product',
    390'202-209':'Reserved',
    391'210':'EPA Air Quality Forecast - Currently North East US domain',
    392'211':'EPA Air Quality Forecast - Currently Eastern US domain',
    393'212-214':'Reserved',
    394'215':'SPC Manual Forecast Product',
    395'216-219':'Reserved',
    396'220':'NCEP/OPC automated product',
    397'221-230':'Reserved for WPC products',
    398'231-254':'Reserved',
    399'255':'Missing',
    400}